
package android.preference;

import com.tizianhoesch.gibmitnews.GIBMITNewsActivity;

import android.app.AlertDialog;
import android.app.AlertDialog.Builder;
import android.content.Context;
import android.content.DialogInterface;
import android.util.AttributeSet;
import android.util.Log;

public class MultiSelectPreference extends ListPreference {
    public static final String SEPARATOR = ", ";

    private String allCheckedSummary = "";

    private boolean[] selectedValueIndices;

    public MultiSelectPreference(Context context, AttributeSet attrs) {
        super(context, attrs);
        selectedValueIndices = new boolean[getEntries().length];
    }

    @Override
    public void setEntries(CharSequence[] entries) {
        super.setEntries(entries);
        selectedValueIndices = new boolean[entries.length];
    }

    @Override
    public void setValue(String value) {
        super.setValue(value);
        refreshSummary();
    }

    public MultiSelectPreference(Context context) {
        this(context, null);
    }

    @Override
    protected void onPrepareDialogBuilder(Builder builder) {
        final CharSequence[] entries = getEntries();
        final CharSequence[] entryValues = getEntryValues();

        if (entries == null || entryValues == null
                || entries.length != entryValues.length) {
            Log.e(GIBMITNewsActivity.TAG, "entries <> entryvalues");
        }

        restoreCheckedEntries();

        builder.setMultiChoiceItems(entries, selectedValueIndices,
                new DialogInterface.OnMultiChoiceClickListener() {
                    public void onClick(DialogInterface dialog, int which,
                            boolean val) {
                        selectedValueIndices[which] = val;
                        if (!val) {
                            ((AlertDialog) dialog).getListView()
                                    .setItemChecked(0, false);
                        } else {
                            int size = selectedValueIndices.length;
                            boolean status = true;
                            for (int i = 1; i < size; i++) {
                                if (!selectedValueIndices[i]) {
                                    status = false;
                                    break;
                                }
                            }
                            ((AlertDialog) dialog).getListView()
                                    .setItemChecked(0, status);
                        }
                    }
                });
    }

    public static String[] parseStoredValue(CharSequence val) {
        if (val == null || "".equals(val))
            return null;
        else
            return ((String) val).split(SEPARATOR);
    }

    private void restoreCheckedEntries() {
        CharSequence[] entryValues = getEntryValues();

        String[] vals = parseStoredValue(getValue());
        if (vals != null) {
            for (int j = 0; j < vals.length; j++) {
                String val = vals[j].trim();
                for (int i = 0; i < entryValues.length; i++) {
                    if (entryValues[i].equals(val)) {
                        selectedValueIndices[i] = true;
                        break;
                    }
                }
            }
        }
    }

    @Override
    protected void onDialogClosed(boolean positiveResult) {
        CharSequence[] entrys = getEntries();
        CharSequence[] entryValues = getEntryValues();
        if (allFalse(selectedValueIndices)) {

        } else {
            if (positiveResult && entryValues != null) {
                StringBuffer entry = new StringBuffer();
                StringBuffer value = new StringBuffer();
                for (int i = 0; i < entryValues.length; i++) {
                    if (selectedValueIndices[i]) {
                        value.append(entryValues[i]).append(SEPARATOR);
                        entry.append(entrys[i]).append(SEPARATOR);
                    }
                }

                String ety = entry.toString();
                String val = value.toString();
                if (val.length() > 0)
                    val = val.substring(0, val.length() - SEPARATOR.length());
                if (ety.length() > 0)
                    ety = ety.substring(0, ety.length() - SEPARATOR.length());
                setValue(val);
                setSummary(ety);

                callChangeListener(value);
            }
        }
    }

    public void refreshSummary() {
        restoreCheckedEntries();
        CharSequence[] entrys = getEntries();
        CharSequence[] entryValues = getEntryValues();

        StringBuffer entry = new StringBuffer("");
        for (int i = 0; i < entryValues.length; i++) {
            if (selectedValueIndices[i]) {
                entry.append(SEPARATOR).append(entrys[i]);
            }
        }

        String ret = entry.toString();
        if (ret.length() > 0)
            ret = ret.substring(1);

        setSummary(ret.substring(1));
    }

    public static boolean allFalse(boolean[] ary) {
        for (int i = 0; i < ary.length; i++) {
            if (ary[i] == true)
                return false;
        }
        return true;
    }

    public String getAllCheckedSummary() {
        return allCheckedSummary;
    }

    public void setAllCheckedSummary(String allCheckedSummary) {
        this.allCheckedSummary = allCheckedSummary;
    }
}
