
package com.handmark.pulltorefresh.library;

import android.content.Context;
import android.util.AttributeSet;
import android.webkit.WebChromeClient;
import android.webkit.WebView;

import com.tizianhoesch.gibmitnews.R;

public class PullToRefreshWebView extends PullToRefreshBase<WebView> {

    private final OnRefreshListener defaultOnRefreshListener = new OnRefreshListener() {

        @Override
        public void onRefresh() {
            mRefreshableView.reload();
        }

    };

    private final WebChromeClient defaultWebChromeClient = new WebChromeClient() {

        @Override
        public void onProgressChanged(WebView view, int newProgress) {
            if (newProgress == 100) {
                onRefreshComplete();
            }
        }

    };

    public PullToRefreshWebView(Context context) {
        super(context);

        /**
         * Added so that by default, Pull-to-Refresh refreshes the page
         */
        setOnRefreshListener(defaultOnRefreshListener);
        mRefreshableView.setWebChromeClient(defaultWebChromeClient);
    }

    public PullToRefreshWebView(Context context, int mode) {
        super(context, mode);

        /**
         * Added so that by default, Pull-to-Refresh refreshes the page
         */
        setOnRefreshListener(defaultOnRefreshListener);
        mRefreshableView.setWebChromeClient(defaultWebChromeClient);
    }

    public PullToRefreshWebView(Context context, AttributeSet attrs) {
        super(context, attrs);

        /**
         * Added so that by default, Pull-to-Refresh refreshes the page
         */
        setOnRefreshListener(defaultOnRefreshListener);
        mRefreshableView.setWebChromeClient(defaultWebChromeClient);
    }

    @Override
    protected WebView createRefreshableView(Context context, AttributeSet attrs) {
        WebView webView = new WebView(context, attrs);

        webView.setId(R.id.webview);
        return webView;
    }

    @Override
    protected boolean isReadyForPullDown() {
        return mRefreshableView.getScrollY() == 0;
    }

    @Override
    protected boolean isReadyForPullUp() {
        int exactContentHeight = (int) Math.floor(mRefreshableView.getContentHeight()
                * mRefreshableView.getScale());
        return mRefreshableView.getScrollY() >= (exactContentHeight - mRefreshableView.getHeight());
    }
}
