
package com.tizianhoesch.gibmitnews.database;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class KlassenlisteDbAdapter {
    private static final String KEY_ROWID = "_id";
    public static final String KEY_KLASSENID = "klassenid";
    public static final String KEY_KLASSENKUERZEL = "klassenkuerzel";
    static final String DATABASE_TABLE = "klassenliste";
    private Context myContext;
    private SQLiteDatabase database;
    private KlassenlisteDatabaseHelper dbHelper;

    public KlassenlisteDbAdapter(Context context) {
        this.myContext = context;
    }

    public KlassenlisteDbAdapter open() throws SQLException {
        dbHelper = new KlassenlisteDatabaseHelper(myContext);
        database = dbHelper.getWritableDatabase();
        return this;
    }

    public void close() {
        if (dbHelper != null) {
            dbHelper.close();
        }
    }

    public long createKlasse(String klassenId, String klassenKuerzel) {
        ContentValues initialValues = createContentValues(klassenId,
                klassenKuerzel);

        return database.insert(DATABASE_TABLE, null, initialValues);
    }

    public Cursor fetchAllKlassen() {
        return database.query(DATABASE_TABLE, new String[] {
                KEY_ROWID,
                KEY_KLASSENID, KEY_KLASSENKUERZEL
        }, null, null, null, null,
                null);
    }

    public Cursor fetchKlasse(String kuerzel) {
        return database.query(DATABASE_TABLE, new String[] {
                KEY_KLASSENID
        },
                KEY_KLASSENKUERZEL + " LIKE '" + kuerzel + "'", null, null,
                null, null);
    }

    private ContentValues createContentValues(String category, String summary) {
        ContentValues values = new ContentValues();
        values.put(KEY_KLASSENID, category);
        values.put(KEY_KLASSENKUERZEL, summary);
        return values;
    }

    public void clearTable() {
        final String DATABASE_DROP = "delete from " + DATABASE_TABLE + ";";

        database.execSQL(DATABASE_DROP);
    }

    public Cursor fetchKlasseByID(String klassenID) {
        return database.query(DATABASE_TABLE,
                new String[] {
                    KEY_KLASSENKUERZEL
                }, KEY_KLASSENID + " LIKE '"
                        + klassenID + "'", null, null, null, null);
    }
}
